package net.sf.corn.cps;

import java.io.Serializable;
import java.net.URL;

/**
 * This is a container class to keep an URL address with it's root URL.
 * This class is intended to use with the resource scanning filter classes.The {@link CPScanner}
 * sends resource URL addresses to filters as RootedURL classes instead of single URL's. Thus filters 
 * can find out package name and file names.
 * @author serhat.dirik
 */
public class RootedURL implements Serializable {
 
	private static final long serialVersionUID = -4967318289335433478L;
	
	private URL rootURL;
	private URL resourceURL;
	/**
	 * Constructs a new RootedURL address
	 * @param rootURL root of the resource URL 
	 * @param resourceURL Full resource URL
	 */
	public RootedURL(URL rootURL, URL resourceURL) {
		if(rootURL == null){
			throw new IllegalArgumentException("Null root URL not accepted!");
		}
		if(resourceURL == null){
			throw new IllegalArgumentException("Null resource URL not accepted!");
		}
		if(! resourceURL.toString().startsWith(rootURL.toString())){
			throw new IllegalArgumentException("The root URL \""+rootURL+"\" is not root of the resource URL \""+resourceURL+"\"");
		}
		
		this.rootURL = rootURL;
		this.resourceURL = resourceURL;
	}
	
	public URL getRootURL() {
		return rootURL;
	}
	public URL getResourceURL() {
		return resourceURL;
	}
	
	/**
	 * Extracts the package name from resource URL 
	 * @return package name 
	 */
	public String getPackageName(){
		String root = rootURL.toString();
		String packageName = resourceURL.toString();
		if(root.equals(packageName)){
			return "";
		}else{
			if(packageName.lastIndexOf('/') >= root.length()){
				packageName = packageName.substring(root.length(),packageName.lastIndexOf('/'));
			}else{
				packageName = "";
			}
			
			return packageName;
		}
	}
	
	/**
	 * Extracts the resource name from resource URL 
	 * @return resource name 
	 */
	public String getResourceName(){
		String root = rootURL.toString();
		String resourceName = resourceURL.toString();
		if(root.equals(resourceName)){
			return null;
		}else{
			if(resourceName.lastIndexOf('/') >= root.length() && resourceName.length() > resourceName.lastIndexOf('/')){
				resourceName = resourceName.substring(resourceName.lastIndexOf('/')+1);
			}else{
				resourceName = null;
			}
			
			return resourceName;
		}
	}
	
	@Override
	public String toString() {
	    return new StringBuilder().append("Root:"+getRootURL()).append(",Resource:").append(getResourceURL()).toString();
	}
	
 
}
